<template>
  <el-dialog
    v-diadrag
    width="60%"
    title="用户"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="user-dialog"
    id="user-dialog"
  >
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="350"
      :ajaxFun="ajaxFun"
      :paramObj="paramObj"
      ref="commonUserTable"
    >
      <template #toolbar></template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import { fetchList } from '@/api/admin/user'
import ttable from '@/views/common/ztt-table'
import { remote } from '../../api/admin/dict'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    multiSelect: {
      type: Boolean,
      default: false
    },
    parentSelectedObj: {
      type: Object,
      default: null
    },
    parentSelectedIndex: {
      type: Number,
      default: null
    }
  },
  data() {
    return {
      ajaxFun: fetchList,
      innerVisible: false,
      listLoading: true,
      currentRow: null,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'commonUser',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        isGenerateId: true,
        isGenerateField: 'userId',
        defaultOrderBy: { column: 'userId', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 版本号
          {
            minWidth: '100',
            prop: 'username',
            label: '用户名',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'staffInfo',
            label: '员工',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'phone',
            label: '手机号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ]
      },
      addOrUpdateVisible: false
    }
  },
  components: {
    ttable
  },
  methods: {
    saveSelectRow() {
      this.$emit('listenToUserEvent', this.currentRow)
      this.innerVisible = false
    },
    handleCurrentChange(row) {
      this.currentRow = row
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    },
    getData() {
      if (this.$refs.commonUserTable !== undefined) {
        this.$refs.commonUserTable.getDataList()
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    }
  },
  mounted() {}
}
</script>
<style>
.user-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.user-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.user-dialog .el-dialog__body {
  padding: 5px 20px;
}

.user-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.user-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
